@@ -26,7 +26,7 @@ class Rox:
     def _reset():
         Rox.State = RoxState.ShuttingDown
 
-        Rox.core.shutdown(True, True)
+        Rox.core.shutdown()
         Rox.core = Core()
 
         Rox.State = RoxState.Idle
@@ -38,7 +38,7 @@ class Rox:
                 Logging.get_logger().warn('Rox can only be shutdown when it is already Set up, skipping Shutdown')
                 return
             else:
-                _reset()
+                Rox._reset()
 
     @staticmethod
     def setup(api_key, rox_options=None):
@@ -48,7 +48,7 @@ class Rox:
                 return
 
             if Rox.State is RoxState.Corrupted:
-                _reset()
+                Rox._reset()
 
             if Rox.State is RoxState.Idle:
                 Rox.State = RoxState.SettingUp
